Lage/Redigere tabell

Lage/Redigere tabell | IF

Lage tabell-knappen åpner et nytt vindu, ved hjelp av dette vinduet kan du lage tabeller.
Feltforklaring:

Kolonner | Antall kolonner i tabellen.
Rader | Antall rader i tabellen.
Celleutfylling | Antall pixler utfylling i hver celle.
Cellemellomrom | Antall pixler mellomrom mellom cellene.
Justering | Tabellens justering.
Rammebredde | Rammens bredde.
Bredde | Bredde i pixler.
Høyde | Høyde i pixler.
Stil | Stilmal på tabellen.

Gå til: Innholdsoversikt | Toppen